from dataclasses import dataclass
from typing import List, Optional


@dataclass
class TrainingExample:
    input: str
    output: str
    id: Optional[str] = None


@dataclass
class UploadResponse:
    id: str


@dataclass
class MetricsQuestions:
    metrics_id: str
    definitions: List[str]


@dataclass
class Question:
    id: str
    input: str
    status: str
    created_at: str
    updated_at: str
    prompt: Optional[str] = None
    stream_id: Optional[str] = None


@dataclass
class MetricsResponse:
    metrics_id: str


@dataclass
class ScoringPair:
    pair_id: str
    score_reason: str


@dataclass
class MetricScore:
    metric: str
    mean_score: float
    std_dev: float
    ci_low: float
    ci_high: float
    ci_confidence: float
    median_score: float
    min_score: float
    max_score: float
    lowest_scoring_pairs: List[ScoringPair]


@dataclass
class EvaluationResponse:
    eval_results_id: str
    scores: List[MetricScore]
    pair_count: int


@dataclass
class PairUploadResponse:
    """Response from uploading a pair to a dataset."""

    dataset_id: str
    pair_id: str



from setuptools import setup, find_packages
import os

# Check if we have a plum_sdk directory with actual code
if not os.path.exists("plum_sdk") and os.path.exists("__init__.py"):
    # We're inside the package directory - use . to include the current directory
    package_dir = {"": "."}
    packages = [""]
else:
    # Regular package structure
    packages = find_packages(include=["plum_sdk", "plum_sdk.*"])
    package_dir = {}

setup(
    name="plum_sdk",
    version="0.1.8",
    packages=packages,
    package_dir=package_dir,
    py_modules=["plum_sdk"] if not packages else [],
    install_requires=["requests"],
    tests_require=["pytest"],
    python_requires=">=3.6",
    description="Python SDK for Plum AI",
    author="Plum AI",
    author_email="founders@getplum.ai",
    url="https://github.com/getplumai/plum_sdk",
    classifiers=[
        "Programming Language :: Python :: 3",
    ],
    extras_require={
        "dev": ["black"],
    },
)
